﻿Function Wait-EMAgentAvailability {

    Param (

        [int]$ActionTimeout=10
    )

    $EMAgentInstallPath = Get-EMInstallPath

    Write-Log -Message "Wait until client is available" -Source "EM-AgentPackage" -LogType "CMTrace"

    if($EMAgentInstallPath) {

        $EMManagedTasksFile = "{0}Settings\ManagedTasks.sxml" -f $EMAgentInstallPath
        $EMActionTimeout = $ActionTimeout

        Write-Log -Message "Check if there is an ManagedTask.sxml File to check for running installations" -Source "EM-AgentPackage" -LogType "CMTrace"
        if(Test-Path $EMManagedTasksFile) {
                
            [bool]$EMActionRunning = $true
            Write-Log -Message "ManagedTask.sxml File exist. Check timestamp of file" -Source "EM-AgentPackage" -LogType "CMTrace"
            while($EMActionRunning -eq $true) {
                    
                $EMManagedTasksLastWriteTime = (Get-ItemProperty -Path "$EMManagedTasksFile").LastWriteTime
                $CurrentDate=(Get-Date)

                if(((New-TimeSpan –Start $EMManagedTasksLastWriteTime –End $CurrentDate).Minutes) -le $EMActionTimeout) {
                    Write-Log -Message "EM-Agent Task is running, waiting 60sec to check again" -Source "EM-AgentPackage" -LogType "CMTrace"
                    Start-Sleep -Seconds 60
                }
                else {
                    $EMActionRunning = $false
                    write-Log -Message  "No EM-Agent Action active. Start uninstalling existing agent." -Source "EM-AgentPackage" -LogType "CMTrace" 
                }
            }
        }
    }
    Write-Log -Message "Client is available now." -Source "EM-AgentPackage" -LogType "CMTrace"
}

Function Get-EMInstallPath {

    # Get current EM-Agent path

    $EMAgentRegPath = "HKLM:\SOFTWARE\WOW6432Node\Matrix42\Matrix42 Enterprise Manager Agent"
    Write-Log -Message "Try to get EM-Agent installation path from x86 registry" -Source "EM-AgentPackage" -LogType "CMTrace"
    
    if(!(Test-RegistryValue -Key $EMAgentRegPath -Value "InstallPath")) {
        
        $EMAgentRegPath = "HKLM:\SOFTWARE\Matrix42\Matrix42 Enterprise Manager Agent"
        Write-Log -Message "Try to get EM-Agent installation path from x64 registry" -Source "EM-AgentPackage" -LogType "CMTrace"
        
        if(!(Test-RegistryValue -Key $EMAgentRegPath -Value "InstallPath")) {
            Write-Log -Message "No installation path found in registry. EM-Agent seems not to be installed." -Source "EM-AgentPackage" -LogType "CMTrace"
        }
        else {
            $EMAgentInstallPath = (Get-ItemProperty -Path $EMAgentRegPath).InstallPath
        }
    }
    else {
        $EMAgentInstallPath = (Get-ItemProperty -Path $EMAgentRegPath).InstallPath
    }

    return $EMAgentInstallPath
}