﻿<#
.SYNOPSIS
	This script is a template that allows you to extend the toolkit with your own custom functions.
.DESCRIPTION
	The script is automatically dot-sourced by the AppDeployToolkitMain.ps1 script.
.NOTES
    Toolkit Exit Code Ranges:
    60000 - 68999: Reserved for built-in exit codes in Deploy-Application.ps1, Deploy-Application.exe, and AppDeployToolkitMain.ps1
    69000 - 69999: Recommended for user customized exit codes in Deploy-Application.ps1
    70000 - 79999: Recommended for user customized exit codes in AppDeployToolkitExtensions.ps1
.LINK 
	http://psappdeploytoolkit.com
#>
[CmdletBinding()]
Param (
)

##*===============================================
##* VARIABLE DECLARATION
##*===============================================

# Variables: Script
[string]$appDeployToolkitExtName = 'PSAppDeployToolkitExt'
[string]$appDeployExtScriptFriendlyName = 'App Deploy Toolkit Extensions'
[version]$appDeployExtScriptVersion = [version]'1.5.0'
[string]$appDeployExtScriptDate = '06/11/2015'
[hashtable]$appDeployExtScriptParameters = $PSBoundParameters

##*===============================================
##* FUNCTION LISTINGS
##*===============================================

# <Your custom functions go here>

#region Register-Installation
Function Register-Installation {
<#
.SYNOPSIS
	Saves state information about the installation in the registry of the target computer.
.DESCRIPTION
	Saves state information about the installation in the registry of the target computer.
.EXAMPLE
	Register-Installation
.NOTES
.LINK
	https://crankdesk.wordpress.com
#>
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'IsInstalled' -Value 1 -Type DWord
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptName' -Value "$appName" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptVendor' -Value "$appVendor" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptVersion' -Value "$appVersion" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptArch' -Value "$appArch" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptLanguage' -Value "$appLang" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptRevision' -Value "$appRevision" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptVersion' -Value "$appScriptVersion" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptDate' -Value "$appScriptDate" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'ScriptAuthor' -Value "$appScriptAuthor" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'PSADKVersion' -Value "$appDeployMainScriptVersion" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'InstallationDateTime' -Value "$currentDateTime" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'InstallationTimeZone' -Value "$currentTimeZoneBias" -Type String
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'InstallationSource' -Value "$scriptParentPath" -Type String
    $logFile = "{0}{1}" -f $logDirectory, $logName
    Set-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName" -Name 'LogFile' -Value "$logFile" -Type String

}
#endregion

#region Deregister-Installation
Function Deregister-Installation {
<#
.SYNOPSIS
	Deletes state information about the installation in the registry of the target computer.
.DESCRIPTION
	Deletes state information about the installation in the registry of the target computer.
.EXAMPLE
	Deregister-Installation
.NOTES
.LINK
	https://crankdesk.wordpress.com
#>
    Remove-RegistryKey -Key "HKEY_LOCAL_MACHINE\SOFTWARE\PSADK\InstalledApps\$appName"
}
#endregion


##*===============================================
##* END FUNCTION LISTINGS
##*===============================================

##*===============================================
##* SCRIPT BODY
##*===============================================

If ($scriptParentPath) {
	Write-Log -Message "Script [$($MyInvocation.MyCommand.Definition)] dot-source invoked by [$(((Get-Variable -Name MyInvocation).Value).ScriptName)]" -Source $appDeployToolkitExtName
}
Else {
	Write-Log -Message "Script [$($MyInvocation.MyCommand.Definition)] invoked directly" -Source $appDeployToolkitExtName
}

##*===============================================
##* END SCRIPT BODY
##*===============================================